@@ -1,3 +1,9 @@
+"""
+MkDocs Plugin.
+
+https://www.mkdocs.org/
+https://github.com/timvink/mkdocs-git-revision-date-localized-plugin/
+"""
 # standard lib
 import logging
 import re
@@ -11,18 +17,29 @@ from mkdocs.utils import copy_file
 
 # package modules
 from mkdocs_git_revision_date_localized_plugin.util import Util
+from mkdocs_git_revision_date_localized_plugin.exclude import exclude
+
+from typing import Any, Dict
 
 HERE = os.path.dirname(os.path.abspath(__file__))
 
+
 class GitRevisionDateLocalizedPlugin(BasePlugin):
+    """
+    Mkdocs plugin to add revision date from Git.
+
+    See https://www.mkdocs.org/user-guide/plugins
+    """
+
     config_scheme = (
         ("fallback_to_build_date", config_options.Type(bool, default=False)),
         ("locale", config_options.Type(str, default=None)),
         ("type", config_options.Type(str, default="date")),
         ("timezone", config_options.Type(str, default="UTC")),
+        ("exclude", config_options.Type(list, default=[])),
     )
 
-    def on_config(self, config: config_options.Config, **kwargs) -> dict:
+    def on_config(self, config: config_options.Config, **kwargs) -> Dict[str, Any]:
         """
         Determine which locale to use.
 
@@ -92,9 +109,12 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
 
         # Add pointers to support files for timeago.js
         if self.config.get("type") == "timeago":
-            config["extra_javascript"] = ["js/timeago_mkdocs_material.js"] + config["extra_javascript"]
-            config["extra_javascript"] = ["js/timeago.locales.min.js"] + config["extra_javascript"]
-            config["extra_javascript"] = ["js/timeago.min.js"] + config["extra_javascript"]
+            config["extra_javascript"] = ["js/timeago_mkdocs_material.js"] + config[
+                "extra_javascript"
+            ]
+            config["extra_javascript"] = ["js/timeago.min.js"] + config[
+                "extra_javascript"
+            ]
             config["extra_css"] = ["css/timeago.css"] + config["extra_css"]
 
         return config
@@ -103,7 +123,7 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
         self, markdown: str, page: Page, config: config_options.Config, files, **kwargs
     ) -> str:
         """
-        Replace jinja2 tags in markdown and templates with the localized dates
+        Replace jinja2 tags in markdown and templates with the localized dates.
 
         The page_markdown event is called after the page's markdown is loaded
         from file and can be used to alter the Markdown source text.
@@ -121,6 +141,11 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
         Returns:
             str: Markdown source text of page as string
         """
+        # Exclude pages specified in config
+        excluded_pages = self.config.get("exclude", [])
+        if exclude(page.file.src_path, excluded_pages):
+            logging.debug("Excluding page " + page.file.src_path)
+            return markdown
 
         revision_dates = self.util.get_revision_date_for_file(
             path=page.file.abs_src_path,
@@ -144,14 +169,19 @@ class GitRevisionDateLocalizedPlugin(BasePlugin):
             flags=re.IGNORECASE,
         )
 
+    def on_post_build(self, config: Dict[str, Any], **kwargs) -> None:
+        """
+        Run on post build.
 
-    def on_post_build(self, config, **kwargs):
-
+        Adds the timeago assets to the build.
+        """
         # Add timeago files:
-        # Current version timeago.js: 2.0.2
         if self.config.get("type") == "timeago":
-            files = ['js/timeago.min.js', 'js/timeago.locales.min.js',
-            'js/timeago_mkdocs_material.js', 'css/timeago.css']
+            files = [
+                "js/timeago.min.js",
+                "js/timeago_mkdocs_material.js",
+                "css/timeago.css",
+            ]
             for file in files:
                 dest_file_path = os.path.join(config["site_dir"], file)
                 src_file_path = os.path.join(HERE, file)
